@@ -1,11 +1,15 @@
 import json
 from typing import Dict, List, Union
 
-from cognite.airworkflow.model.project import Project
+PROJECT_FUNCTION_MAP = "ProjectFunctionMap"
+PROJECT_PROPERTIES = "Projectproperties"
 
 
 class Config:
-    def __init__(self, config: Dict):
+    def __init__(self, config: Dict, function_name: str, repoconfig: Dict):
+        self.function_name = function_name
+        self.repoconfig = repoconfig
+
         model_settings = config["modelSettings"]
         model_description = config["modelDescription"]
 
@@ -15,7 +19,7 @@ class Config:
         self.description: str = model_description["description"]
         self.long_description: str = model_description["longDescription"]
 
-        self.deploy: List[Project] = list(map(Project, model_settings["deploy"]))
+        self.deploy: List[str] = self._retrieve_deployment_information()
         self.model_version: str = model_settings["modelVersion"]
         self.send_alerts: bool = bool(model_settings["sendAlerts"])
         self.display_in_front_end: bool = bool(model_settings["displayInFrontEnd"])
@@ -28,6 +32,11 @@ class Config:
             Visualization(config.get("visualization", {})) if config.get("visualization") else None
         )
 
+    def _retrieve_deployment_information(self) -> List[str]:
+        project_function_map = self.repoconfig.get(PROJECT_FUNCTION_MAP, {}).get(self.function_name, [])
+        projects = list(self.repoconfig[PROJECT_PROPERTIES].keys())
+        return project_function_map or projects
+
     def to_dict(self):
         convert = {
             "description": self.description,
