@@ -1,20 +1,30 @@
 import os
 import sys
 from itertools import product
+from pathlib import Path
 
 import cognite.airworkflow.constants as const
 from cognite.airworkflow.function_deployer import FunctionDeployer
-from cognite.airworkflow.master_config import get_deployments, get_master_config
+from cognite.airworkflow.master_config import get_master_config, get_parallel_deployment, write_dependency_yamls
 from cognite.airworkflow.model.schedule_assets import execute
 from cognite.airworkflow.model_asset_hierarchy import ModelAssetHierarchy
-from cognite.airworkflow.util import cdf, env, functions, github
+from cognite.airworkflow.util import cdf, env, functions, github, yaml
 
 
 def handle_asset_hierarchy():
-    _, project_to_config = get_master_config()
-    for project, config in project_to_config.items():
-        print(f"Running Model Asset Hierarchy create/update for project {project}")
-        ModelAssetHierarchy(config, project).create_or_update()
+    function_name, project = sys.argv[3].split("@")
+    function_name_path = Path(function_name)
+    function_path = const.FUNCTIONS_PATH / function_name_path / const.FUNCTION_REL_CONFIG_PATH
+    master_config = {
+        function_path.parent.parent: yaml.load_and_validate(function_path, const.CONFIG_SCHEMA_PATH, function_name)
+    }
+    write_dependency_yamls(master_config)
+    if len(sys.argv) >= 2:
+        airInfra = sys.argv[2] == "True"
+    else:
+        airInfra = False
+    print(f"Running Model Asset Hierarchy create/update for project {project}")
+    ModelAssetHierarchy(master_config, project, airInfra).create_or_update()
 
 
 def handle_function_deployments():
@@ -22,14 +32,12 @@ def handle_function_deployments():
     github_ref = env.get_env_value("GITHUB_REF")
     is_delete = "IS_DELETE" in os.environ and os.environ["IS_DELETE"] == "true"
     is_pr = github_event_name == "pull_request"
-
     assert (
         len(sys.argv) >= 3 and sys.argv[2]
     ), "Expected a function name passed as a command line argument, but got nothing"
-    function_name = sys.argv[2].split("/")[-1] if "/" in sys.argv[2] else sys.argv[2]
+    function_name, project_name = sys.argv[2].split("@")
     print(f"HANDLING {github_event_name} ON {github_ref} FOR FUNCTION {function_name}")
-
-    for deployment in get_deployments(function_name):
+    for deployment in get_parallel_deployment(function_name, project_name):
         FunctionDeployer(deployment, is_delete, is_pr).handle_deployment()
 
 
@@ -47,7 +55,7 @@ def handle_delete_functions():
             functions.get_function_name(f, pr=True, ref=ref) for ref, f in list(product(pr_refs, function_paths))
         ]
 
-        info = const.PROJECT_TO_API_KEYS[project]
+        info = const.PROJECTS_TO_API_KEYS[project]
         client = cdf.experimental_client(info.project)
         dangling = functions.list_dangling_function(client, all_functions, name_prefix=env.get_repo_name_auto())
         for function in dangling:
@@ -57,7 +65,7 @@ def handle_delete_functions():
 def handle_deploy_infrastructure_schedules():
     _, project_to_config = get_master_config()
     for project, config_dict in project_to_config.items():
-        info = const.PROJECT_TO_API_KEYS[project]
+        info = const.PROJECTS_TO_API_KEYS[project]
         client = cdf.experimental_client(info.project)
         execute(client)
 
@@ -66,11 +74,37 @@ def handle_call_schedulemanager():
     _, project_to_config = get_master_config()
     for project in project_to_config:
         client = cdf.experimental_client(project)
-        client.functions.call(external_id="cognitedata/air-functions/schedulemanager:latest", wait=False)
+        client.functions.call(external_id=const.SCHEDULEMANAGER_EXTERNAL_ID, wait=False)
+
+
+def handle_check_deployment():
+    function_name, project_name = sys.argv[2].split("@")
+    client = cdf.experimental_client(project_name)
+    model_asset = client.assets.retrieve(external_id=function_name)
+    if model_asset is None:
+        print(str(True))
+        return str(True)
+
+    # check if function has been deployed
+    repo_name = env.get_env_value("GITHUB_REPOSITORY")
+    function_external_id = str(repo_name) + "/" + str(function_name) + ":latest"
+
+    function_asset = client.functions.retrieve(external_id=function_external_id)
+    if function_asset is None:
+        print(str(True))
+        return str(True)
+
+    cdf_model_version = model_asset.metadata["modelVersion"]
+    configuration = get_master_config()[1][project_name]
+    key1 = [i for i in configuration.keys() if i.parts[-1] == function_name][0]
+    model_version = configuration[key1].model_version
+    model_version = ".".join(model_version.split(".")[:-1])
+    already_deployed = str(model_version != cdf_model_version)
+    print(already_deployed)
+    return already_deployed
 
 
 if __name__ == "__main__":
-
     if sys.argv[1] == "model":
         handle_asset_hierarchy()
     elif sys.argv[1] == "function":
@@ -81,3 +115,5 @@ if __name__ == "__main__":
         handle_deploy_infrastructure_schedules()
     elif sys.argv[1] == "call_schedulemanager":
         handle_call_schedulemanager()
+    elif sys.argv[1] == "check_deployment":
+        handle_check_deployment()
