@@ -8,7 +8,6 @@ from cognite.client import CogniteClient
 from cognite.experimental import CogniteClient as ExperimentalClient
 
 from cognite.airworkflow.constants import PROJECTS_TO_API_KEYS
-from cognite.airworkflow.model.project import Project
 
 os.environ["COGNITE_MAX_RETRIES"] = "5"
 os.environ["COGNITE_TIMEOUT"] = "120"
@@ -17,9 +16,8 @@ os.environ["COGNITE_TIMEOUT"] = "120"
 def data_set_id(client: CogniteClient, name: str) -> int:
     data_sets = client.data_sets.list(limit=-1).dump()
     for ds in data_sets:
-        if ds["name"] == name:
+        if ("archived" not in ds["metadata"] or ds["metadata"]["archived"] != "true") and ds["name"] == name:
             return ds["id"]
-
     raise LookupError(f"Not able to find dataset named {name}")
 
 
@@ -64,10 +62,10 @@ def await_function_deployment(client: ExperimentalClient, function_name: str, ma
     return False
 
 
-def experimental_client(project: Project, api_key: str = "", base_url: str = None) -> ExperimentalClient:
+def experimental_client(project: str, api_key: str = "", base_url: str = None) -> ExperimentalClient:
     return ExperimentalClient(
         api_key=api_key if api_key else PROJECTS_TO_API_KEYS[project].get_client_api_key(),
         client_name="AIR Functions Client",
-        project=project.value,
+        project=project,
         base_url=base_url if base_url else PROJECTS_TO_API_KEYS[project].base_url,
     )
